@@ -3,10 +3,10 @@
 use strict;
 use warnings;
 
-use XML::LibXML;
+use XML::LibXML ();
 
-use Getopt::Long;
-use Pod::Usage;
+use Getopt::Long qw/ GetOptions /;
+use Pod::Usage qw/ pod2usage /;
 
 sub _esc
 {
@@ -33,13 +33,13 @@ sub _esc_for_attr
     return $ret;
 }
 
-
 my $xml_uri = q{http://www.w3.org/XML/1998/namespace};
-my $xpc = XML::LibXML::XPathContext->new();
+my $xpc     = XML::LibXML::XPathContext->new();
+
 # $xpc->registerNs('x', q{http://www.w3.org/1999/xhtml});
-$xpc->registerNs('db', q{http://docbook.org/ns/docbook});
-$xpc->registerNs('xlink', q{http://www.w3.org/1999/xlink});
-$xpc->registerNs('xml', $xml_uri);
+$xpc->registerNs( 'db',    q{http://docbook.org/ns/docbook} );
+$xpc->registerNs( 'xlink', q{http://www.w3.org/1999/xlink} );
+$xpc->registerNs( 'xml',   $xml_uri );
 
 my $parser = XML::LibXML->new();
 
@@ -47,19 +47,19 @@ $parser->load_ext_dtd(0);
 
 my $output_file;
 my $help = 0;
-my $man = 0;
-my $ret = GetOptions(
+my $man  = 0;
+my $ret  = GetOptions(
     "o|output=s" => \$output_file,
-    "help|h" => \$help,
-    "man" => \$man,
+    "help|h"     => \$help,
+    "man"        => \$man,
 );
 
-if (!defined($output_file))
+if ( !defined($output_file) )
 {
     die "Unspecified output file. Type --help for more information.\n";
 }
 
-if (!$ret)
+if ( !$ret )
 {
     pod2usage(2);
 }
@@ -69,63 +69,66 @@ if ($help)
 }
 if ($man)
 {
-    pod2usage(-exitstatus => 0, -verbose => 2)
+    pod2usage( -exitstatus => 0, -verbose => 2 );
 }
 
 my $input_file = shift(@ARGV);
 
-if (!defined($input_file))
+if ( !defined($input_file) )
 {
     die "Unspecified input file. Type --help for more information.\n";
 }
 
 my $doc = $parser->parse_file($input_file);
 
-my ($main_title) = $xpc->findnodes(q{/db:article/db:info/db:title}, $doc);
+my ($main_title)    = $xpc->findnodes( q{/db:article/db:info/db:title}, $doc );
 my $main_title_text = $main_title->textContent();
-my ($main_article) = $xpc->findnodes(q{/db:article}, $doc);
-my $main_id_text = $main_article->getAttributeNS($xml_uri, "id");
+my ($main_article)  = $xpc->findnodes( q{/db:article}, $doc );
+my $main_id_text    = $main_article->getAttributeNS( $xml_uri, "id" );
 
-
-my @sections = $xpc->findnodes(q{/db:article/db:section}, $doc);
+my @sections = $xpc->findnodes( q{/db:article/db:section}, $doc );
 
 sub _out_section
 {
     my $sect_elem = shift;
 
-    my $id = $sect_elem->getAttributeNS($xml_uri, "id");
+    my $id = $sect_elem->getAttributeNS( $xml_uri, "id" );
 
-    my ($title_elem) = $xpc->findnodes(q{./db:info/db:title}, $sect_elem);
+    my ($title_elem) = $xpc->findnodes( q{./db:info/db:title}, $sect_elem );
 
     my $title_text = $title_elem->textContent();
 
-    my @paras = $xpc->findnodes(q{./db:para}, $sect_elem);
+    my @paras = $xpc->findnodes( q{./db:para}, $sect_elem );
 
-    my @subs = $xpc->findnodes(q{./db:section}, $sect_elem);
+    my @subs = $xpc->findnodes( q{./db:section}, $sect_elem );
 
     return
-          qq{<s id="} . _esc_for_attr($id) . qq{">\n\n}
-        . qq{<title>} . _esc($title_text) . qq{</title>\n\n}
-        .  join("\n\n", map { _esc($_->textContent()) } @paras)
-        . join("\n\n", map { _out_section($_) } @subs)
-        . qq{</s>\n\n}
-        ;
+          qq{<s id="}
+        . _esc_for_attr($id)
+        . qq{">\n\n}
+        . qq{<title>}
+        . _esc($title_text)
+        . qq{</title>\n\n}
+        . join( "\n\n", map { _esc( $_->textContent() ) } @paras )
+        . join( "\n\n", map { _out_section($_) } @subs )
+        . qq{</s>\n\n};
 }
 
 my $total =
-      qq{<body id="} . _esc_for_attr($main_id_text) . qq{">\n\n}
-    . qq{<title>} . _esc($main_title_text) . qq{</title>\n\n}
-    . join("\n\n", map { _out_section($_) } @sections)
-    . qq{</body>\n\n}
-    ;
+      qq{<body id="}
+    . _esc_for_attr($main_id_text)
+    . qq{">\n\n}
+    . qq{<title>}
+    . _esc($main_title_text)
+    . qq{</title>\n\n}
+    . join( "\n\n", map { _out_section($_) } @sections )
+    . qq{</body>\n\n};
 
-open my $out_fh, ">", $output_file
+open my $out_fh, ">:encoding(utf-8)", $output_file
     or die "Could not open '$output_file' for output!";
-binmode $out_fh, ":encoding(utf-8)";
 print {$out_fh} $total;
 close($out_fh);
 
-
 __END__
 
 =head1 NAME
