@@ -1,14 +1,20 @@
 package XML::Grammar::Fiction;
-
-use warnings;
+$XML::Grammar::Fiction::VERSION = '0.18.0';
 use strict;
+use warnings;
 
-=encoding utf8
 
-=head1 NAME
+1;
 
-XML::Grammar::Fiction - CPAN distribution implementing an XML grammar
-and a lightweight markup language for stories, novels and other fiction.
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 VERSION
+
+version 0.18.0
 
 =head1 SYNOPSIS
 
@@ -43,6 +49,11 @@ L<XML::Grammar::Screenplay> .
 
 The rest of this page will document the syntax of the custom textual format.
 
+=head1 NAME
+
+XML::Grammar::Fiction - CPAN distribution implementing an XML grammar
+and a lightweight markup language for stories, novels and other fiction.
+
 =head1 FORMAT
 
 =head2 Sections
@@ -154,7 +165,6 @@ An unordered list.
 
     </body>
 
-
 =head3 Other Examples
 
 Examples can be found in the C<t/data> directory, and here:
@@ -191,7 +201,126 @@ so you'll need to accept that some modifications to your sources will be
 required in the future. I hope you still find it useful and let me know
 if you need any feature or bug-fix.
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/XML-Grammar-Fiction>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::Grammar::Fiction>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-grammar-fiction at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/fiction-xml>
+
+  git clone git://github.com/shlomif/fiction-xml.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/fiction-xml/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2007 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
-
-1;
-
