@@ -1,42 +1,39 @@
 package XML::Grammar::Fiction::App::ToDocBook;
-$XML::Grammar::Fiction::App::ToDocBook::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::App::ToDocBook::VERSION = '0.18.0';
 use strict;
 use warnings;
 use autodie;
 
-use base 'Exporter';
+use parent 'Exporter';
 
 our @EXPORT = (qw(run));
 
-use Getopt::Long;
-
-use XML::Grammar::Fiction::ToDocBook;
+use Getopt::Long qw/ GetOptions /;
 
+use XML::Grammar::Fiction::ToDocBook ();
 
 
 sub run
 {
-    my $output_filename;
+    my $output_fn;
 
-    GetOptions(
-        "output|o=s" => \$output_filename,
-    );
+    GetOptions( "output|o=s" => \$output_fn, );
 
-    if (!defined($output_filename))
+    if ( !defined($output_fn) )
     {
         die "Output filename not specified! Use the -o|--output flag!";
     }
 
     my $converter = XML::Grammar::Fiction::ToDocBook->new();
 
-    my $output_text = $converter->translate_to_docbook({
+    my $output_text = $converter->translate_to_docbook(
+        {
             source => { file => shift(@ARGV), },
             output => "string",
         }
     );
 
-    open my $out, ">", $output_filename;
-    binmode $out, ":utf8";
+    open my $out, ">:encoding(utf-8)", $output_fn;
     print {$out} $output_text;
     close($out);
 
@@ -51,13 +48,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::App::ToDocBook
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 SYNOPSIS
 
@@ -69,10 +62,6 @@ version v0.16.0
 XML::Grammar::Fiction::App::ToDocBook - command line app-in-a-module
 to convert a Fiction XML file to DocBook 5.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head1 FUNCTIONS
 
 =head2 run()
@@ -176,9 +165,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -187,9 +176,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
