@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node;
-$XML::Grammar::Fiction::FromProto::Node::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::FromProto::Node::VERSION = '0.18.0';
 use strict;
 use warnings;
 
@@ -10,13 +10,10 @@ use MooX 'late';
 
 sub _short_isa
 {
-    my $self = shift;
+    my $self         = shift;
     my $isa_classish = shift;
 
-    return
-        $self->isa(
-            "XML::Grammar::Fiction::FromProto::Node::$isa_classish"
-        );
+    return $self->isa("XML::Grammar::Fiction::FromProto::Node::$isa_classish");
 }
 
 1;
@@ -27,13 +24,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::FromProto::Node
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 DESCRIPTION
 
@@ -44,10 +37,6 @@ Contains several nodes.
 XML::Grammar::Fiction::FromProto::Node - contains several nodes for
 use in XML::Grammar::Fiction::FromProto.
 
-=head1 VERSION
-
-version v0.16.0
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -145,9 +134,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -156,9 +145,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
