@@ -1,27 +1,28 @@
 package XML::Grammar::Fiction::FromProto::Node::Element;
-$XML::Grammar::Fiction::FromProto::Node::Element::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::FromProto::Node::Element::VERSION = '0.18.0';
+
 use strict;
 use warnings;
 
-
 use MooX 'late';
 
 extends("XML::Grammar::Fiction::FromProto::Node::WithContent");
 
-has 'name' => (isa => 'Str', is => 'rw');
-has 'attrs' => (isa => 'ArrayRef', is => 'rw');
-has 'open_line' => (isa => 'Maybe[Int]', is => 'rw');
+has 'name'      => ( isa => 'Str',        is => 'rw' );
+has 'attrs'     => ( isa => 'ArrayRef',   is => 'rw' );
+has 'open_line' => ( isa => 'Maybe[Int]', is => 'rw' );
 
 
 sub lookup_attr
 {
-    my ($self, $attr_name) = @_;
+    my ( $self, $attr_name ) = @_;
 
-    my $pair = List::Util::first { $_->{key} eq $attr_name } (@{$self->attrs()});
+    my $pair =
+        List::Util::first { $_->{key} eq $attr_name } ( @{ $self->attrs() } );
 
-    if (!defined($pair))
+    if ( !defined($pair) )
     {
-        return undef;
+        return;
     }
     else
     {
@@ -37,22 +38,14 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::FromProto::Node::Element
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Fiction::FromProto::Node::Element - an XML element node.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head1 METHODS
 
 =head2 lookup_attr
@@ -156,9 +149,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -167,9 +160,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
