@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node::Text;
-$XML::Grammar::Fiction::FromProto::Node::Text::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::FromProto::Node::Text::VERSION = '0.18.0';
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ extends("XML::Grammar::Fiction::FromProto::Node::WithContent");
 
 sub get_text
 {
-    my ($self, $re) = @_;
+    my ( $self, $re ) = @_;
 
     return $self->children->contents->[0];
 }
@@ -23,13 +23,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::FromProto::Node::Text
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 METHODS
 
@@ -134,9 +130,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -145,9 +141,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
