@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node::WithContent;
-$XML::Grammar::Fiction::FromProto::Node::WithContent::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::FromProto::Node::WithContent::VERSION = '0.18.0';
 use strict;
 use warnings;
 
@@ -9,7 +9,8 @@ use MooX 'late';
 extends("XML::Grammar::Fiction::FromProto::Node");
 
 has 'children' => (
-    is => 'rw'
+    isa => 'XML::Grammar::Fiction::FromProto::Node::List',
+    is  => 'rw'
 );
 
 sub _get_childs
@@ -29,29 +30,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::FromProto::Node::WithContent
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Fiction::FromProto::Node::WithContent - contains a node
 with content.
 
-=head1 VERSION
-
-version v0.16.0
-
-=head1 METHODS
-
-=head2 children()
-
-TODO FILL IN.
-
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -149,9 +136,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -160,9 +147,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
