@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Parser::QnD;
-$XML::Grammar::Fiction::FromProto::Parser::QnD::VERSION = 'v0.16.0';
+$XML::Grammar::Fiction::FromProto::Parser::QnD::VERSION = '0.18.0';
 use strict;
 use warnings;
 
@@ -7,12 +7,13 @@ use MooX 'late';
 
 extends("XML::Grammar::FictionBase::FromProto::Parser::XmlIterator");
 
-use XML::Grammar::Fiction::Struct::Tag;
-use XML::Grammar::Fiction::Err;
-use XML::Grammar::FictionBase::Event;
+use XML::Grammar::Fiction::Struct::Tag ();
+use XML::Grammar::Fiction::Err         ();
+use XML::Grammar::FictionBase::Event   ();
 
 
-sub _non_tag_text_unit_consume_regex {
+sub _non_tag_text_unit_consume_regex
+{
     return qr{(?:[\<]|^\n?$)}ms;
 }
 
@@ -24,34 +25,35 @@ sub _generate_non_tag_text_event
 
     my $status = $self->_parse_non_tag_text_unit();
 
-    if (!defined($status))
+    if ( !defined($status) )
     {
         return;
     }
 
-    my $elem = $status->{'elem'};
+    my $elem        = $status->{'elem'};
     my $is_para_end = $status->{'para_end'};
 
     my $in_para = $self->_in_para();
-    if ($is_para && !$in_para)
+    if ( $is_para && !$in_para )
     {
         $self->_enqueue_event(
             XML::Grammar::FictionBase::Event->new(
-               { type => "open", tag => "para", }
+                { type => "open", tag => "para", }
             ),
         );
         $in_para = 1;
     }
 
-    if (my ($rest) = $elem->get_text() =~ m{\A\+(.*)}ms)
+    if ( my ($rest) = $elem->get_text() =~ m{\A\+(.*)}ms )
     {
         if ( length($rest) )
         {
             $self->throw_text_error(
-                'XML::Grammar::Fiction::Err::Parse::ParaOpenPlusNotFollowedByTag',
+'XML::Grammar::Fiction::Err::Parse::ParaOpenPlusNotFollowedByTag',
                 "Got a paragraph opening plus sign not followed by a tag.",
             );
         }
+
         # Else - do nothing - just ignore the + sign before the
         # style tag.
     }
@@ -59,12 +61,12 @@ sub _generate_non_tag_text_event
     {
         $self->_enqueue_event(
             XML::Grammar::FictionBase::Event->new(
-                {type => "elem", elem => $elem}
+                { type => "elem", elem => $elem }
             )
         );
     }
 
-    if ($is_para_end && $in_para)
+    if ( $is_para_end && $in_para )
     {
         $self->_enqueue_event(
             XML::Grammar::FictionBase::Event->new(
@@ -89,21 +91,20 @@ sub _calc_open_para
 {
     my $self = shift;
 
-    return
-        XML::Grammar::Fiction::Struct::Tag::Para->new(
-            name => "p",
-            is_standalone => 0,
-            line => $self->line_num(),
-            attrs => [],
-            children => [],
-        );
+    return XML::Grammar::Fiction::Struct::Tag::Para->new(
+        name          => "p",
+        is_standalone => 0,
+        line          => $self->line_num(),
+        attrs         => [],
+        children      => [],
+    );
 }
 
 sub _handle_open_para
 {
-    my ($self, $event) = @_;
+    my ( $self, $event ) = @_;
 
-    $self->_push_tag($self->_calc_open_para());
+    $self->_push_tag( $self->_calc_open_para() );
 
     $self->_in_para(1);
 
@@ -112,14 +113,11 @@ sub _handle_open_para
 
 sub _handle_close_para
 {
-    my ($self, $event) = @_;
+    my ( $self, $event ) = @_;
 
     my $open = $self->_pop_tag;
 
-    my $new_elem =
-        $self->_new_para(
-            $open->detach_children(),
-        );
+    my $new_elem = $self->_new_para( $open->detach_children(), );
 
     $self->_add_to_top_tag($new_elem);
 
@@ -145,10 +143,10 @@ sub _look_ahead_for_tag
 
     my $l = $self->curr_line_copy();
 
-    my $is_tag_cond = ($$l =~ m{\G<}cg);
-    my $is_close = $is_tag_cond && ($$l =~ m{\G/}cg);
+    my $is_tag_cond = ( $$l =~ m{\G<}cg );
+    my $is_close = $is_tag_cond && ( $$l =~ m{\G/}cg );
 
-    return ($is_tag_cond, $is_close);
+    return ( $is_tag_cond, $is_close );
 }
 
 sub _main_loop_iter_body_prelude
@@ -177,23 +175,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Fiction::FromProto::Parser::QnD
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Fiction::FromProto::Parser::QnD - Quick and Dirty parser
 for the Fiction-XML proto-text.
 
-=head1 VERSION
-
-version v0.16.0
-
 B<For internal use only>.
 
 =head1 METHODS
@@ -303,9 +293,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -314,9 +304,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
