@@ -1,28 +1,28 @@
 package XML::Grammar::FictionBase::FromProto::Parser::LineIterator;
-$XML::Grammar::FictionBase::FromProto::Parser::LineIterator::VERSION = 'v0.16.0';
+$XML::Grammar::FictionBase::FromProto::Parser::LineIterator::VERSION = '0.18.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
-use XML::Grammar::Fiction::Err;
+use XML::Grammar::Fiction::Err ();
 
 extends("XML::Grammar::Fiction::FromProto::Parser");
 
-has "_curr_line_idx" => (isa => "Int", is => "rw", reader => "line_idx",);
-has "_lines" => (isa => "ArrayRef", is => "rw");
+has "_curr_line_idx" => ( isa => "Int", is => "rw", reader => "line_idx", );
+has "_lines" => ( isa => "ArrayRef", is => "rw" );
 
 
 sub setup_text
 {
-    my ($self, $text) = @_;
+    my ( $self, $text ) = @_;
 
     # We include the lines trailing newlines for safety.
-    $self->_lines([split(/^/, $text)]);
+    $self->_lines( [ split( /^/, $text ) ] );
 
     $self->_curr_line_idx(0);
 
-    ${$self->curr_line_ref()} =~ m{\A}g;
+    ${ $self->curr_line_ref() } =~ m{\A}g;
 
     return;
 }
@@ -32,7 +32,7 @@ sub curr_line_ref
 {
     my $self = shift;
 
-    return \($self->_lines()->[$self->_curr_line_idx()]);
+    return \( $self->_lines()->[ $self->_curr_line_idx() ] );
 }
 
 
@@ -40,7 +40,7 @@ sub curr_pos
 {
     my $self = shift;
 
-    return pos(${$self->curr_line_ref()});
+    return pos( ${ $self->curr_line_ref() } );
 }
 
 
@@ -48,7 +48,7 @@ sub at_line_start
 {
     my $self = shift;
 
-    return ($self->curr_pos == 0);
+    return ( $self->curr_pos == 0 );
 }
 
 
@@ -56,7 +56,7 @@ sub curr_line_and_pos
 {
     my $self = shift;
 
-    return ($self->curr_line_ref(), $self->curr_pos());
+    return ( $self->curr_line_ref(), $self->curr_pos() );
 }
 
 
@@ -64,7 +64,7 @@ sub curr_line_copy
 {
     my $self = shift;
 
-    my $l = ${$self->curr_line_ref()} . "";
+    my $l = ${ $self->curr_line_ref() } . "";
 
     pos($l) = $self->curr_pos();
 
@@ -76,10 +76,11 @@ sub next_line_ref
 {
     my $self = shift;
 
-    $self->_curr_line_idx($self->_curr_line_idx()+1);
+    $self->_curr_line_idx( $self->_curr_line_idx() + 1 );
 
-    if (! $self->eof() ) {
-        pos(${$self->curr_line_ref()}) = 0;
+    if ( !$self->eof() )
+    {
+        pos( ${ $self->curr_line_ref() } ) = 0;
     }
 
     return $self->curr_line_ref();
@@ -101,7 +102,7 @@ sub skip_multiline_space
 {
     my $self = shift;
 
-    if (${$self->curr_line_ref()} =~ m{\G.*?\S})
+    if ( ${ $self->curr_line_ref() } =~ m{\G.*?\S} )
     {
         return;
     }
@@ -114,7 +115,7 @@ sub skip_multiline_space
 
 sub curr_line_continues_with
 {
-    my ($self, $re) = @_;
+    my ( $self, $re ) = @_;
 
     my $l = $self->curr_line_ref();
 
@@ -126,7 +127,7 @@ sub line_num
 {
     my $self = shift;
 
-    return $self->_curr_line_idx()+1;
+    return $self->_curr_line_idx() + 1;
 }
 
 
@@ -136,9 +137,9 @@ sub _next_line_ref_wo_leading_space
 
     my $l = $self->next_line_ref();
 
-    if (defined($$l))
+    if ( defined($$l) )
     {
-        $self->_check_if_line_starts_with_whitespace()
+        $self->_check_if_line_starts_with_whitespace();
     }
 
     return $l;
@@ -146,12 +147,12 @@ sub _next_line_ref_wo_leading_space
 
 sub consume
 {
-    my ($self, $match_regex) = @_;
+    my ( $self, $match_regex ) = @_;
 
     my $return_value = "";
-    my $l = $self->curr_line_ref();
+    my $l            = $self->curr_line_ref();
 
-    while (defined($$l) && ($$l =~ m[\G(${match_regex}*)\z]cgms))
+    while ( defined($$l) && ( $$l =~ m[\G(${match_regex}*)\z]cgms ) )
     {
         $return_value .= $$l;
     }
@@ -160,7 +161,7 @@ sub consume
         $l = $self->_next_line_ref_wo_leading_space();
     }
 
-    if (defined($$l) && ($$l =~ m[\G(${match_regex}*)]cg))
+    if ( defined($$l) && ( $$l =~ m[\G(${match_regex}*)]cg ) )
     {
         $return_value .= $1;
     }
@@ -172,21 +173,21 @@ sub consume
 # TODO : copied and pasted from _consume - abstract
 sub consume_up_to
 {
-    my ($self, $match_regex) = @_;
+    my ( $self, $match_regex ) = @_;
 
     my $return_value = "";
-    my $l = $self->curr_line_ref();
+    my $l            = $self->curr_line_ref();
 
-    LINE_LOOP:
-    while (defined($$l))
+LINE_LOOP:
+    while ( defined($$l) )
     {
         # We assign to a scalar for scalar context, but we're not making
         # use of the variable.
-        my $verdict = ($$l =~ m[\G(.*?)((?:${match_regex})|\z)]cgms);
+        my $verdict = ( $$l =~ m[\G(.*?)((?:${match_regex})|\z)]cgms );
         $return_value .= $1;
 
         # Find if it matched the regex.
-        if (length($2) > 0)
+        if ( length($2) > 0 )
         {
             last LINE_LOOP;
         }
@@ -202,20 +203,19 @@ sub consume_up_to
 
 sub throw_text_error
 {
-    my ($self, $error_class, $text) = @_;
+    my ( $self, $error_class, $text ) = @_;
 
     return $error_class->throw(
         error => $text,
-        line => $self->line_num(),
+        line  => $self->line_num(),
     );
 }
 
-
 sub _check_if_line_starts_with_whitespace
 {
     my $self = shift;
 
-    if (${$self->curr_line_ref()} =~ m{\A[ \t]})
+    if ( ${ $self->curr_line_ref() } =~ m{\A[ \t]} )
     {
         $self->throw_text_error(
             'XML::Grammar::Fiction::Err::Parse::LeadingSpace',
@@ -229,7 +229,7 @@ sub eof
 {
     my $self = shift;
 
-    return (!defined( ${ $self->curr_line_ref() } ));
+    return ( !defined( ${ $self->curr_line_ref() } ) );
 }
 
 
@@ -241,13 +241,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::FictionBase::FromProto::Parser::LineIterator
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 SYNOPSIS
 
@@ -263,10 +259,6 @@ and process it incrementally.
 XML::Grammar::FictionBase::FromProto::Parser::LineIterator - line iterator base
 class for the parser.
 
-=head1 VERSION
-
-version v0.16.0
-
 B<For internal use only>.
 
 =head1 METHODS
@@ -479,9 +471,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -490,9 +482,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
