@@ -1,11 +1,11 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = 'v0.16.0';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.18.0';
 use strict;
 use warnings;
 
 use MooX 'late';
 
-use XML::Writer;
+use XML::Writer    ();
 use HTML::Entities ();
 
 sub _get_xml_xml_ns
@@ -19,17 +19,17 @@ sub _get_xlink_xml_ns
 }
 
 
-has '_parser_class' =>
-(
-    is => "ro",
-    isa => "Str",
+has '_parser_class' => (
+    is       => "ro",
+    isa      => "Str",
     init_arg => "parser_class",
-    default => "XML::Grammar::Fiction::FromProto::Parser::QnD",
+    default  => "XML::Grammar::Fiction::FromProto::Parser::QnD",
 );
 
 has "_parser" => (
-    'is' => "rw",
-    lazy => 1,
+    'isa'   => "XML::Grammar::Fiction::FromProto::Parser",
+    'is'    => "rw",
+    lazy    => 1,
     default => sub {
         my $self = shift;
         return $self->_parser_class->new();
@@ -41,14 +41,13 @@ sub _get_initial_writer
     my $self = shift;
 
     my $writer = XML::Writer->new(
-        OUTPUT => $self->_buffer(),
-        ENCODING => "utf-8",
+        OUTPUT     => $self->_buffer(),
+        ENCODING   => "utf-8",
         NAMESPACES => 1,
-        PREFIX_MAP =>
-        {
+        PREFIX_MAP => {
             $self->_get_default_xml_ns() => "",
-            $self->_get_xml_xml_ns() => 'xml',
-            $self->_get_xlink_xml_ns() => 'xlink',
+            $self->_get_xml_xml_ns()     => 'xml',
+            $self->_get_xlink_xml_ns()   => 'xlink',
         },
     );
 
@@ -58,19 +57,21 @@ sub _get_initial_writer
 }
 
 has "_writer" => (
-    'is' => "rw",
-    lazy => 1,
+    'isa'   => "Maybe[XML::Writer]",
+    'is'    => "rw",
+    lazy    => 1,
     default => sub { return shift->_get_initial_writer(); },
 );
 
-sub _get_initial_buffer {
+sub _get_initial_buffer
+{
     my $buffer = '';
     return \$buffer;
 }
 
 has '_buffer' => (
-    is => "rw",
-    lazy => 1,
+    is      => "rw",
+    lazy    => 1,
     default => sub { return shift->_get_initial_buffer; },
 );
 
@@ -78,8 +79,8 @@ sub _reset_buffer
 {
     my $self = shift;
 
-    $self->_buffer($self->_get_initial_buffer());
-    $self->_writer($self->_get_initial_writer());
+    $self->_buffer( $self->_get_initial_buffer() );
+    $self->_writer( $self->_get_initial_writer() );
 
     return;
 }
@@ -94,35 +95,34 @@ sub _flush_buffer
     return $ret;
 }
 
-my %passthrough_elem =
-(
+my %passthrough_elem = (
     b => sub { return shift->_bold_tag_name(); },
     i => sub { return shift->_italics_tag_name(); },
 );
 
 sub _calc_passthrough_cb
 {
-    my ($self, $name) = @_;
+    my ( $self, $name ) = @_;
 
-    if (exists($passthrough_elem{$name}))
+    if ( exists( $passthrough_elem{$name} ) )
     {
         return $passthrough_elem{$name};
     }
     else
     {
-        return undef();
+        return;
     }
 }
 
 sub _calc_passthrough_name
 {
-    my ($self, $name, $elem) = @_;
+    my ( $self, $name, $elem ) = @_;
 
     my $cb = $self->_calc_passthrough_cb($name);
 
-    if (ref($cb) eq 'CODE')
+    if ( ref($cb) eq 'CODE' )
     {
-        return $cb->($self, $name, $elem,);
+        return $cb->( $self, $name, $elem, );
     }
     else
     {
@@ -132,11 +132,11 @@ sub _calc_passthrough_name
 
 sub _write_elem
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $elem = $args->{elem};
 
-    if (ref($elem) eq "")
+    if ( ref($elem) eq "" )
     {
         $self->_writer->characters($elem);
     }
@@ -148,33 +148,33 @@ sub _write_elem
 
 sub _write_Element_Paragraph
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
     return $self->_output_tag_with_childs(
         {
-            start => [$self->_paragraph_tag()],
-            elem => $elem,
+            start => [ $self->_paragraph_tag() ],
+            elem  => $elem,
         },
     );
 }
 
 sub _write_Element_Element
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
     return $self->_write_Element_elem($elem);
 }
 
 sub _write_Element_Comment
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
     my $text = $elem->text();
 
     # To avoid trailing space due to a problem in XML::Writer
     $text =~ s{\A[\r\n]+}{}ms;
 
-    if ($text =~ m{\n\z})
+    if ( $text =~ m{\n\z} )
     {
         $text .= ' ';
     }
@@ -189,24 +189,25 @@ sub _calc_write_elem_obj_classes
 
 sub _output_tag_with_childs
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    return
-        $self->_output_tag({
+    return $self->_output_tag(
+        {
             %$args,
             'in' => sub {
                 return $self->_write_elem_childs( $args->{elem} );
             },
-        });
+        }
+    );
 }
 
 sub _write_elem_childs
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
-    foreach my $child (@{$elem->_get_childs()})
+    foreach my $child ( @{ $elem->_get_childs() } )
     {
-        $self->_write_elem({ elem => $child,},);
+        $self->_write_elem( { elem => $child, }, );
     }
 
     return;
@@ -214,13 +215,13 @@ sub _write_elem_childs
 
 sub _write_elem_obj
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $elem = $args->{elem};
 
-    foreach my $class (@{$self->_calc_write_elem_obj_classes()})
+    foreach my $class ( @{ $self->_calc_write_elem_obj_classes() } )
     {
-        if ($elem->_short_isa($class))
+        if ( $elem->_short_isa($class) )
         {
             my $meth = "_write_Element_$class";
             $self->$meth($elem);
@@ -228,31 +229,33 @@ sub _write_elem_obj
         }
     }
 
-    Carp::confess("Class of element not detected - " . ref($elem) . "!");
+    Carp::confess( "Class of element not detected - " . ref($elem) . "!" );
 }
 
 sub _write_Element_elem
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
     my $name = $elem->name();
 
-    if ($elem->_short_isa("InnerDesc"))
+    if ( $elem->_short_isa("InnerDesc") )
     {
         $self->_output_tag_with_childs(
             {
                 start => ["inlinedesc"],
-                elem => $elem,
+                elem  => $elem,
             }
         );
         return;
     }
-    elsif (defined(my $out_name = $self->_calc_passthrough_name($name, $elem)))
+    elsif (
+        defined( my $out_name = $self->_calc_passthrough_name( $name, $elem ) )
+        )
     {
         return $self->_output_tag_with_childs(
             {
                 start => [$out_name],
-                elem => $elem,
+                elem  => $elem,
             }
         );
     }
@@ -268,14 +271,14 @@ sub _write_Element_elem
 
 sub _handle_elem_of_name_s
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
-    $self->_write_scene({scene => $elem});
+    $self->_write_scene( { scene => $elem } );
 }
 
 sub _handle_elem_of_name_br
 {
-    my ($self, $elem) = @_;
+    my ( $self, $elem ) = @_;
 
     $self->_writer->emptyTag("br");
 
@@ -284,27 +287,25 @@ sub _handle_elem_of_name_br
 
 sub _output_tag
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    my @start = @{$args->{start}};
-    $self->_writer->startTag([$self->_get_default_xml_ns(),$start[0]], @start[1..$#start]);
+    my @start = @{ $args->{start} };
+    $self->_writer->startTag( [ $self->_get_default_xml_ns(), $start[0] ],
+        @start[ 1 .. $#start ] );
 
-    $args->{in}->($self, $args);
+    $args->{in}->( $self, $args );
 
     $self->_writer->endTag();
 }
 
 sub _convert_while_handling_errors
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     eval {
-        my $output_xml = $self->convert(
-            $args->{convert_args},
-        );
+        my $output_xml = $self->convert( $args->{convert_args}, );
 
-        open my $out, ">", $args->{output_filename};
-        binmode $out, ":utf8";
+        open my $out, ">:encoding(UTF-8)", $args->{output_filename};
         print {$out} $output_xml;
         close($out);
     };
@@ -312,36 +313,43 @@ sub _convert_while_handling_errors
     # Error handling.
 
     my $e;
-    if ($e = Exception::Class->caught("XML::Grammar::Fiction::Err::Parse::TagsMismatch"))
+    if (
+        $e = Exception::Class->caught(
+            "XML::Grammar::Fiction::Err::Parse::TagsMismatch")
+        )
     {
         warn $e->error(), "\n";
         warn "Open: ", $e->opening_tag->name(),
-            " at line ", $e->opening_tag->line(), "\n"
-            ;
+            " at line ", $e->opening_tag->line(), "\n";
         warn "Close: ",
             $e->closing_tag->name(), " at line ",
             $e->closing_tag->line(), "\n";
 
         exit(-1);
     }
-    elsif ($e = Exception::Class->caught("XML::Grammar::Fiction::Err::Parse::LineError"))
+    elsif (
+        $e = Exception::Class->caught(
+            "XML::Grammar::Fiction::Err::Parse::LineError")
+        )
     {
         warn $e->error(), "\n";
         warn "At line ", $e->line(), "\n";
         exit(-1);
     }
-    elsif ($e = Exception::Class->caught("XML::Grammar::Fiction::Err::Parse::TagNotClosedAtEOF"))
+    elsif (
+        $e = Exception::Class->caught(
+            "XML::Grammar::Fiction::Err::Parse::TagNotClosedAtEOF")
+        )
     {
         warn $e->error(), "\n";
         warn "Open: ", $e->opening_tag->name(),
-            " at line ", $e->opening_tag->line(), "\n"
-            ;
+            " at line ", $e->opening_tag->line(), "\n";
 
         exit(-1);
     }
-    elsif ($e = Exception::Class->caught())
+    elsif ( $e = Exception::Class->caught() )
     {
-        if (ref($e))
+        if ( ref($e) )
         {
             $e->rethrow();
         }
@@ -356,11 +364,10 @@ sub _convert_while_handling_errors
 
 sub _read_file
 {
-    my ($self, $filename) = @_;
+    my ( $self, $filename ) = @_;
 
-    open my $in, "<", $filename or
-        Carp::confess("Could not open the file \"$filename\" for slurping.");
-    binmode $in, ":utf8";
+    open my $in, "<:encoding(UTF-8)", $filename
+        or Carp::confess("Could not open the file \"$filename\" for slurping.");
     my $contents;
     {
         local $/;
@@ -373,23 +380,23 @@ sub _read_file
 
 sub _calc_tree
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
-    my $filename = $args->{source}->{file} or
-        confess "Wrong filename given.";
+    my $filename = $args->{source}->{file}
+        or confess "Wrong filename given.";
 
-    return $self->_parser->process_text($self->_read_file($filename));
+    return $self->_parser->process_text( $self->_read_file($filename) );
 }
 
 sub _write_scene
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $scene = $args->{scene};
 
     my $tag = $scene->name;
 
-    if (($tag eq "s") || ($tag eq "scene"))
+    if ( ( $tag eq "s" ) || ( $tag eq "scene" ) )
     {
         $self->_write_scene_main($scene);
     }
@@ -404,17 +411,17 @@ sub _write_scene
 
 sub convert
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $tree = $self->_calc_tree($args);
-    if (!defined($tree))
+    if ( !defined($tree) )
     {
         Carp::confess("Parsing failed.");
     }
 
     $self->_convert_write_content($tree);
 
-    return ${$self->_flush_buffer()};
+    return ${ $self->_flush_buffer() };
 }
 
 
@@ -426,23 +433,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::FictionBase::TagsTree2XML
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::FictionBase::TagsTree2XML - base class for the tags-tree
 to XML converters.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head2 $self->convert({ source => { file => $path_to_file } })
 
 Converts the file $path_to_file to XML and returns it. Throws an exception
@@ -549,9 +548,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -560,9 +559,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
