@@ -1,47 +1,45 @@
 package XML::Grammar::Screenplay::App::FromProto;
-$XML::Grammar::Screenplay::App::FromProto::VERSION = 'v0.16.0';
+$XML::Grammar::Screenplay::App::FromProto::VERSION = '0.18.0';
 use strict;
 use warnings;
 use autodie;
 
-use base 'Exporter';
+use parent 'Exporter';
 
 our @EXPORT = (qw(run));
 
-use Getopt::Long;
+use Getopt::Long qw/ GetOptions /;
 
-use XML::Grammar::Screenplay::FromProto;
-use XML::Grammar::Screenplay::FromProto::Parser::QnD;
+use XML::Grammar::Screenplay::FromProto              ();
+use XML::Grammar::Screenplay::FromProto::Parser::QnD ();
 
 
 sub run
 {
     my $output_filename;
 
-    GetOptions(
-        "output|o=s" => \$output_filename,
-    );
+    GetOptions( "output|o=s" => \$output_filename, );
 
-    if (!defined($output_filename))
+    if ( !defined($output_filename) )
     {
         die "Output filename not specified! Use the -o|--output flag!";
     }
 
-    my $converter = XML::Grammar::Screenplay::FromProto->new({
-        parser_class => "XML::Grammar::Screenplay::FromProto::Parser::QnD",
-    });
+    my $converter = XML::Grammar::Screenplay::FromProto->new(
+        {
+            parser_class => "XML::Grammar::Screenplay::FromProto::Parser::QnD",
+        }
+    );
 
     $converter->_convert_while_handling_errors(
         {
-            convert_args =>
-            {
+            convert_args => {
                 source => { file => shift(@ARGV), },
             },
             output_filename => $output_filename,
         }
     );
 
-
     exit(0);
 }
 
@@ -53,13 +51,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Screenplay::App::FromProto
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 SYNOPSIS
 
@@ -72,10 +66,6 @@ XML::Grammar::Screenplay::App::FromProto - module implementing
 a command line application to convert a well-formed text to
 Screenplay XML.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head1 FUNCTIONS
 
 =head2 run()
@@ -179,9 +169,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -190,9 +180,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
