@@ -1,41 +1,39 @@
 package XML::Grammar::Screenplay::App::ToHTML;
-$XML::Grammar::Screenplay::App::ToHTML::VERSION = 'v0.16.0';
+$XML::Grammar::Screenplay::App::ToHTML::VERSION = '0.18.0';
 use strict;
 use warnings;
 use autodie;
 
-use base 'Exporter';
+use parent 'Exporter';
 
 our @EXPORT = (qw(run));
 
-use Getopt::Long;
+use Getopt::Long qw/ GetOptions /;
 
-use XML::Grammar::Screenplay::ToHTML;
+use XML::Grammar::Screenplay::ToHTML ();
 
 
 sub run
 {
     my $output_filename;
 
-    GetOptions(
-        "output|o=s" => \$output_filename,
-    );
+    GetOptions( "output|o=s" => \$output_filename, );
 
-    if (!defined($output_filename))
+    if ( !defined($output_filename) )
     {
         die "Output filename not specified! Use the -o|--output flag!";
     }
 
     my $converter = XML::Grammar::Screenplay::ToHTML->new();
 
-    my $output_text = $converter->translate_to_html({
+    my $output_text = $converter->translate_to_html(
+        {
             source => { file => shift(@ARGV), },
             output => "string",
         }
     );
 
-    open my $out, ">", $output_filename;
-    binmode $out, ":utf8";
+    open my $out, ">:encoding(UTF-8)", $output_filename;
     print {$out} $output_text;
     close($out);
 
@@ -50,23 +48,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Screenplay::App::ToHTML
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Screenplay::App::ToHTML - module implementing
 a command line application to convert a Screenplay XML file to HTML
 
-=head1 VERSION
-
-version v0.16.0
-
 =head1 FUNCTIONS
 
 =head2 run()
@@ -170,9 +160,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -181,9 +171,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
