@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::Base;
-$XML::Grammar::Screenplay::Base::VERSION = 'v0.16.0';
+$XML::Grammar::Screenplay::Base::VERSION = '0.18.0';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use warnings;
 sub new
 {
     my $class = shift;
-    my $self = {};
+    my $self  = {};
 
     bless $self, $class;
 
@@ -24,23 +24,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Screenplay::Base
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Screenplay::Base - base class for XML::Grammar::Screenplay
 classes.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head1 METHODS
 
 =head2 $package->new({%args});
@@ -144,9 +136,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -155,9 +147,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
