@@ -1,10 +1,10 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = 'v0.16.0';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.18.0';
 use strict;
 use warnings;
 use autodie;
 
-use Carp;
+use Carp ();
 
 use MooX 'late';
 
@@ -115,12 +115,7 @@ sub _write_scene_main
     }
 
     my $title = $scene->lookup_attr("title");
-    my $lang  = $scene->lookup_attr("lang");
     my @t     = ( defined($title) ? ( title => $title ) : () );
-    if ( defined($lang) )
-    {
-        push @t, ( [ $self->_get_xml_xml_ns, 'lang' ] => $lang );
-    }
 
     $self->_output_tag_with_childs(
         {
@@ -166,23 +161,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-XML::Grammar::Screenplay::FromProto
-
 =head1 VERSION
 
-version v0.16.0
+version 0.18.0
 
 =head1 NAME
 
 XML::Grammar::Screenplay::FromProto - module that converts well-formed
 text representing a screenplay to an XML format.
 
-=head1 VERSION
-
-version v0.16.0
-
 =head2 new()
 
 Accepts no arguments so far. May take some time as the grammar is compiled
@@ -293,9 +280,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+L<https://github.com/shlomif/fiction-xml>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
+  git clone git://github.com/shlomif/fiction-xml.git
 
 =head1 AUTHOR
 
@@ -304,9 +291,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
-to
-L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
+L<https://github.com/shlomif/fiction-xml/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
